@@ -14,13 +14,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import unicode_literals
-
 import logging
+from unittest import mock
+import warnings
 
-import mock
 from oslotest import base as test_base
-import six
 import testtools
 
 from oslo_i18n import _message
@@ -43,7 +41,7 @@ class MessageTestCase(test_base.BaseTestCase):
 
     def test_message_is_unicode(self):
         message = _message.Message('some %s') % 'message'
-        self.assertIsInstance(message, six.text_type)
+        self.assertIsInstance(message, str)
 
     @mock.patch('locale.getdefaultlocale')
     @mock.patch('gettext.translation')
@@ -64,11 +62,11 @@ class MessageTestCase(test_base.BaseTestCase):
         # The base representation of the message is in Spanish, as well as
         # the default translation, since the default locale was Spanish.
         self.assertEqual(es_translation, message)
-        self.assertEqual(es_translation, message.translate())
+        self.assertEqual(es_translation, message.translation())
 
-    def test_translate_returns_unicode(self):
+    def test_translation_returns_unicode(self):
         message = _message.Message('some %s') % 'message'
-        self.assertIsInstance(message.translate(), six.text_type)
+        self.assertIsInstance(message.translation(), str)
 
     def test_mod_with_named_parameters(self):
         msgid = ("%(description)s\nCommand: %(cmd)s\n"
@@ -84,8 +82,8 @@ class MessageTestCase(test_base.BaseTestCase):
         result = _message.Message(msgid) % params
 
         expected = msgid % params
-        self.assertEqual(result, expected)
-        self.assertEqual(result.translate(), expected)
+        self.assertEqual(expected, result)
+        self.assertEqual(expected, result.translation())
 
     def test_multiple_mod_with_named_parameter(self):
         msgid = ("%(description)s\nCommand: %(cmd)s\n"
@@ -130,7 +128,7 @@ class MessageTestCase(test_base.BaseTestCase):
         self.assertIsNot(expected, first)
 
         # Final translations should be the same
-        self.assertEqual(expected.translate(), first.translate())
+        self.assertEqual(expected.translation(), first.translation())
 
     def test_mod_with_named_parameters_no_space(self):
         msgid = ("Request: %(method)s http://%(server)s:"
@@ -144,8 +142,8 @@ class MessageTestCase(test_base.BaseTestCase):
         result = _message.Message(msgid) % params
 
         expected = msgid % params
-        self.assertEqual(result, expected)
-        self.assertEqual(result.translate(), expected)
+        self.assertEqual(expected, result)
+        self.assertEqual(expected, result.translation())
 
     def test_mod_with_dict_parameter(self):
         msgid = "Test that we can inject a dictionary %s"
@@ -155,7 +153,7 @@ class MessageTestCase(test_base.BaseTestCase):
 
         expected = msgid % params
         self.assertEqual(expected, result)
-        self.assertEqual(expected, result.translate())
+        self.assertEqual(expected, result.translation())
 
     def test_mod_with_wrong_field_type_in_trans(self):
         msgid = "Correct type %(arg1)s"
@@ -169,11 +167,8 @@ class MessageTestCase(test_base.BaseTestCase):
             # Now set up ugettext to return the translated version of
             # the original message, with a bad format string.
             wrong_type = u'Wrong type %(arg1)d'
-            if six.PY3:
-                trans.return_value.gettext.return_value = wrong_type
-            else:
-                trans.return_value.ugettext.return_value = wrong_type
-            trans_result = result.translate()
+            trans.return_value.gettext.return_value = wrong_type
+            trans_result = result.translation()
             expected = msgid % params
             self.assertEqual(expected, trans_result)
 
@@ -181,16 +176,15 @@ class MessageTestCase(test_base.BaseTestCase):
         msgid = "Test that we handle unused args %(arg1)d"
         params = {'arg1': 'test1'}
 
-        self.assertRaises(TypeError, lambda: _message.Message(msgid) % params)
+        with testtools.ExpectedException(TypeError):
+            _message.Message(msgid) % params
 
     def test_mod_with_missing_arg(self):
         msgid = "Test that we handle missing args %(arg1)s %(arg2)s"
         params = {'arg1': 'test1'}
 
-        e = self.assertRaises(KeyError,
-                              lambda: _message.Message(msgid) % params)
-        self.assertIn('arg2', six.text_type(e),
-                      'Missing key \'arg2\' was not flagged')
+        with testtools.ExpectedException(KeyError, '.*arg2.*'):
+            _message.Message(msgid) % params
 
     def test_mod_with_integer_parameters(self):
         msgid = "Some string with params: %d"
@@ -204,12 +198,12 @@ class MessageTestCase(test_base.BaseTestCase):
 
         for message, result in zip(messages, results):
             self.assertEqual(type(result), _message.Message)
-            self.assertEqual(result.translate(), message)
+            self.assertEqual(message, result.translation())
 
             # simulate writing out as string
-            result_str = '%s' % result.translate()
+            result_str = '%s' % result.translation()
             self.assertEqual(result_str, message)
-            self.assertEqual(result, message)
+            self.assertEqual(message, result)
 
     def test_mod_copies_parameters(self):
         msgid = "Found object: %(current_value)s"
@@ -220,7 +214,7 @@ class MessageTestCase(test_base.BaseTestCase):
         changing_dict['current_value'] = 2
         # Even if the param changes when the message is
         # translated it should use the original param
-        self.assertEqual(result.translate(), 'Found object: 1')
+        self.assertEqual('Found object: 1', result.translation())
 
     def test_mod_deep_copies_parameters(self):
         msgid = "Found list: %(current_list)s"
@@ -232,26 +226,26 @@ class MessageTestCase(test_base.BaseTestCase):
         changing_list.append(4)
         # Even though the list changed the message
         # translation should use the original list
-        self.assertEqual(result.translate(), "Found list: [1, 2, 3]")
+        self.assertEqual("Found list: [1, 2, 3]", result.translation())
 
     def test_mod_deep_copies_param_nodeep_param(self):
         msgid = "Value: %s"
         params = utils.NoDeepCopyObject(5)
         # Apply the params
         result = _message.Message(msgid) % params
-        self.assertEqual(result.translate(), "Value: 5")
+        self.assertEqual("Value: 5", result.translation())
 
     def test_mod_deep_copies_param_nodeep_dict(self):
         msgid = "Values: %(val1)s %(val2)s"
         params = {'val1': 1, 'val2': utils.NoDeepCopyObject(2)}
         # Apply the params
         result = _message.Message(msgid) % params
-        self.assertEqual(result.translate(), "Values: 1 2")
+        self.assertEqual("Values: 1 2", result.translation())
 
         # Apply again to make sure other path works as well
         params = {'val1': 3, 'val2': utils.NoDeepCopyObject(4)}
         result = _message.Message(msgid) % params
-        self.assertEqual(result.translate(), "Values: 3 4")
+        self.assertEqual("Values: 3 4", result.translation())
 
     def test_mod_returns_a_copy(self):
         msgid = "Some msgid string: %(test1)s %(test2)s"
@@ -261,16 +255,16 @@ class MessageTestCase(test_base.BaseTestCase):
 
         self.assertIsNot(message, m1)
         self.assertIsNot(message, m2)
-        self.assertEqual(m1.translate(),
+        self.assertEqual(m1.translation(),
                          msgid % {'test1': 'foo', 'test2': 'bar'})
-        self.assertEqual(m2.translate(),
+        self.assertEqual(m2.translation(),
                          msgid % {'test1': 'foo2', 'test2': 'bar2'})
 
     def test_mod_with_none_parameter(self):
         msgid = "Some string with params: %s"
         message = _message.Message(msgid) % None
         self.assertEqual(msgid % None, message)
-        self.assertEqual(msgid % None, message.translate())
+        self.assertEqual(msgid % None, message.translation())
 
     def test_mod_with_missing_parameters(self):
         msgid = "Some string with params: %s %s"
@@ -287,11 +281,11 @@ class MessageTestCase(test_base.BaseTestCase):
         result = _message.Message(msgid) % params
 
         expected = msgid % params
-        self.assertEqual(result, expected)
-        self.assertEqual(result.translate(), expected)
+        self.assertEqual(expected, result)
+        self.assertEqual(expected, result.translation())
 
         # Make sure unused params still there
-        self.assertEqual(result.params.keys(), params.keys())
+        self.assertEqual(params.keys(), result.params.keys())
 
     def test_add_disabled(self):
         msgid = "A message"
@@ -303,14 +297,8 @@ class MessageTestCase(test_base.BaseTestCase):
         test_me = lambda: utils.SomeObject('test') + _message.Message(msgid)
         self.assertRaises(TypeError, test_me)
 
-    @testtools.skipIf(six.PY3, 'test specific to Python 2')
-    def test_str_disabled(self):
-        msgid = "A message"
-        test_me = lambda: str(_message.Message(msgid))
-        self.assertRaises(UnicodeError, test_me)
-
     @mock.patch('gettext.translation')
-    def test_translate(self, mock_translation):
+    def test_translation(self, mock_translation):
         en_message = 'A message in the default locale'
         es_translation = 'A message in Spanish'
         message = _message.Message(en_message)
@@ -320,7 +308,7 @@ class MessageTestCase(test_base.BaseTestCase):
         translator = fakes.FakeTranslations.translator(translations_map)
         mock_translation.side_effect = translator
 
-        self.assertEqual(es_translation, message.translate('es'))
+        self.assertEqual(es_translation, message.translation('es'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_from_unicoded_object(self, mock_translation):
@@ -335,9 +323,9 @@ class MessageTestCase(test_base.BaseTestCase):
         # Here we are not testing the Message object directly but the result
         # of unicoding() an object whose unicode representation is a Message
         obj = utils.SomeObject(message)
-        unicoded_obj = six.text_type(obj)
+        unicoded_obj = str(obj)
 
-        self.assertEqual(es_translation, unicoded_obj.translate('es'))
+        self.assertEqual(es_translation, unicoded_obj.translation('es'))
 
     @mock.patch('gettext.translation')
     def test_translate_multiple_languages(self, mock_translation):
@@ -353,11 +341,11 @@ class MessageTestCase(test_base.BaseTestCase):
         translator = fakes.FakeTranslations.translator(translations_map)
         mock_translation.side_effect = translator
 
-        self.assertEqual(es_translation, message.translate('es'))
-        self.assertEqual(zh_translation, message.translate('zh'))
-        self.assertEqual(en_message, message.translate(None))
-        self.assertEqual(en_message, message.translate('en'))
-        self.assertEqual(en_message, message.translate('XX'))
+        self.assertEqual(es_translation, message.translation('es'))
+        self.assertEqual(zh_translation, message.translation('zh'))
+        self.assertEqual(en_message, message.translation(None))
+        self.assertEqual(en_message, message.translation('en'))
+        self.assertEqual(en_message, message.translation('XX'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_param(self, mock_translation):
@@ -374,12 +362,13 @@ class MessageTestCase(test_base.BaseTestCase):
 
         default_translation = message_with_params % param
         expected_translation = es_translation % param
-        self.assertEqual(expected_translation, msg.translate('es'))
-        self.assertEqual(default_translation, msg.translate('XX'))
+        self.assertEqual(expected_translation, msg.translation('es'))
+        self.assertEqual(default_translation, msg.translation('XX'))
 
     @mock.patch('gettext.translation')
     @mock.patch('oslo_i18n._message.LOG')
-    def test_translate_message_bad_translation(self, mock_log,
+    def test_translate_message_bad_translation(self,
+                                               mock_log,
                                                mock_translation):
         message_with_params = 'A message: %s'
         es_translation = 'A message in Spanish: %s %s'
@@ -389,15 +378,27 @@ class MessageTestCase(test_base.BaseTestCase):
         translator = fakes.FakeTranslations.translator({'es': translations})
         mock_translation.side_effect = translator
 
-        msg = _message.Message(message_with_params)
-        msg = msg % param
-        self.assertFalse(mock_log.debug.called)
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            msg = _message.Message(message_with_params)
+            msg = msg % param
+            default_translation = message_with_params % param
+
+            self.assertEqual(default_translation, msg.translation('es'))
+
+            self.assertEqual(1, len(w))
+            # Note(gibi): in python 3.4 str.__repr__ does not put the unicode
+            # marker 'u' in front of the string representations so the test
+            # removes that to have the same result in python 2.7 and 3.4
+            self.assertEqual("Failed to insert replacement values into "
+                             "translated message A message in Spanish: %s %s "
+                             "(Original: 'A message: %s'): "
+                             "not enough arguments for format string",
+                             str(w[0].message).replace("u'", "'"))
 
-        default_translation = message_with_params % param
-        self.assertEqual(default_translation, msg.translate('es'))
         mock_log.debug.assert_called_with(('Failed to insert replacement '
-                                           'values into translated message %s '
-                                           '(Original: %r): %s'),
+                                           'values into translated message '
+                                           '%s (Original: %r): %s'),
                                           es_translation,
                                           message_with_params,
                                           mock.ANY)
@@ -405,7 +406,8 @@ class MessageTestCase(test_base.BaseTestCase):
     @mock.patch('gettext.translation')
     @mock.patch('locale.getdefaultlocale', return_value=('es', ''))
     @mock.patch('oslo_i18n._message.LOG')
-    def test_translate_message_bad_default_translation(self, mock_log,
+    def test_translate_message_bad_default_translation(self,
+                                                       mock_log,
                                                        mock_local,
                                                        mock_translation):
         message_with_params = 'A message: %s'
@@ -417,10 +419,23 @@ class MessageTestCase(test_base.BaseTestCase):
         mock_translation.side_effect = translator
 
         msg = _message.Message(message_with_params)
-        msg = msg % param
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            msg = msg % param
+            self.assertEqual(1, len(w))
+            # Note(gibi): in python 3.4 str.__repr__ does not put the unicode
+            # marker 'u' in front of the string representations so the test
+            # removes that to have the same result in python 2.7 and 3.4
+            self.assertEqual("Failed to insert replacement values into "
+                             "translated message A message in Spanish: %s %s "
+                             "(Original: 'A message: %s'): "
+                             "not enough arguments for format string",
+                             str(w[0].message).replace("u'", "'"))
+
         mock_log.debug.assert_called_with(('Failed to insert replacement '
-                                           'values into translated message %s '
-                                           '(Original: %r): %s'),
+                                           'values into translated message '
+                                           '%s (Original: %r): %s'),
                                           es_translation,
                                           message_with_params,
                                           mock.ANY)
@@ -428,7 +443,7 @@ class MessageTestCase(test_base.BaseTestCase):
 
         default_translation = message_with_params % param
         self.assertEqual(default_translation, msg)
-        self.assertFalse(mock_log.debug.called)
+        self.assertFalse(mock_log.warning.called)
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_object_param(self, mock_translation):
@@ -454,8 +469,8 @@ class MessageTestCase(test_base.BaseTestCase):
         default_translation = message_with_params % param
         expected_translation = es_translation % param_translation
 
-        self.assertEqual(expected_translation, msg.translate('es'))
-        self.assertEqual(default_translation, msg.translate('XX'))
+        self.assertEqual(expected_translation, msg.translation('es'))
+        self.assertEqual(default_translation, msg.translation('XX'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_param_from_unicoded_obj(self,
@@ -475,10 +490,10 @@ class MessageTestCase(test_base.BaseTestCase):
         expected_translation = es_translation % param
 
         obj = utils.SomeObject(msg)
-        unicoded_obj = six.text_type(obj)
+        unicoded_obj = str(obj)
 
-        self.assertEqual(expected_translation, unicoded_obj.translate('es'))
-        self.assertEqual(default_translation, unicoded_obj.translate('XX'))
+        self.assertEqual(expected_translation, unicoded_obj.translation('es'))
+        self.assertEqual(default_translation, unicoded_obj.translation('XX'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_message_parameter(self, mock_translation):
@@ -498,8 +513,8 @@ class MessageTestCase(test_base.BaseTestCase):
 
         default_translation = message_with_params % message_param
         expected_translation = es_translation % es_param_translation
-        self.assertEqual(expected_translation, msg.translate('es'))
-        self.assertEqual(default_translation, msg.translate('XX'))
+        self.assertEqual(expected_translation, msg.translation('es'))
+        self.assertEqual(default_translation, msg.translation('XX'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_message_parameters(self, mock_translation):
@@ -525,8 +540,8 @@ class MessageTestCase(test_base.BaseTestCase):
                                                      another_message_param)
         expected_translation = es_translation % (es_param_translation,
                                                  another_es_param_translation)
-        self.assertEqual(expected_translation, msg.translate('es'))
-        self.assertEqual(default_translation, msg.translate('XX'))
+        self.assertEqual(expected_translation, msg.translation('es'))
+        self.assertEqual(default_translation, msg.translation('XX'))
 
     @mock.patch('gettext.translation')
     def test_translate_message_with_named_parameters(self, mock_translation):
@@ -546,8 +561,8 @@ class MessageTestCase(test_base.BaseTestCase):
 
         default_translation = message_with_params % {'param': message_param}
         expected_translation = es_translation % {'param': es_param_translation}
-        self.assertEqual(expected_translation, msg.translate('es'))
-        self.assertEqual(default_translation, msg.translate('XX'))
+        self.assertEqual(expected_translation, msg.translation('es'))
+        self.assertEqual(default_translation, msg.translation('XX'))
 
     @mock.patch('locale.getdefaultlocale')
     @mock.patch('gettext.translation')
@@ -588,12 +603,12 @@ class MessageTestCase(test_base.BaseTestCase):
         # Because sys.getdefaultlocale() was Spanish,
         # the default translation will be to Spanish
         self.assertEqual(es_translation, msg)
-        self.assertEqual(es_translation, msg.translate())
-        self.assertEqual(es_translation, msg.translate('es'))
+        self.assertEqual(es_translation, msg.translation())
+        self.assertEqual(es_translation, msg.translation('es'))
 
         # Translation into other locales still works
-        self.assertEqual(zh_translation, msg.translate('zh'))
-        self.assertEqual(fr_translation, msg.translate('fr'))
+        self.assertEqual(zh_translation, msg.translation('zh'))
+        self.assertEqual(fr_translation, msg.translation('fr'))
 
 
 class TranslateMsgidTest(test_base.BaseTestCase):
